# etlx
[![pipeline status](https://gitlab.com/kedikx/etlx/badges/develop/pipeline.svg)](https://gitlab.com/kedikx/etlx/pipelines)
[![coverage report](https://gitlab.com/kedikx/etlx/badges/develop/coverage.svg)](https://kedikx.gitlab.io/etlx/)

